@@ -50,12 +50,13 @@
 #include "akregator_options.h"
 #include <Libkdepim/BroadcastStatus>
 #include "akregator-version.h"
+#include "unityservicemanager.h"
 #include <kio/filecopyjob.h>
 #include <knotifyconfigwidget.h>
 #include <kaboutdata.h>
 #include <kconfig.h>
 #include <kconfigdialog.h>
-#include <qfiledialog.h>
+#include <QFileDialog>
 #include <kmessagebox.h>
 
 #include <QTemporaryFile>
@@ -117,7 +118,7 @@ static QDomDocument createDefaultFeedList()
 
     QDomElement linuxFeeds = doc.createElement(QStringLiteral("outline"));
     linuxFeeds.setAttribute(QStringLiteral("text"), i18n("Linux.com"));
-    linuxFeeds.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("https://www.linux.com/feeds/rss"));
+    linuxFeeds.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("https://www.linux.com/feed/"));
     mainFolder.appendChild(linuxFeeds);
 
     QDomElement planetkde = doc.createElement(QStringLiteral("outline"));
@@ -130,16 +131,6 @@ static QDomDocument createDefaultFeedList()
     apps.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("https://store.kde.org/content.rdf"));
     mainFolder.appendChild(apps);
 
-    // Brazilian Portuguese feeds
-    QDomElement portugueuseFolder = doc.createElement(QStringLiteral("outline"));
-    portugueuseFolder.setAttribute(QStringLiteral("text"), i18n("Brazilian Portuguese feeds"));
-    mainFolder.appendChild(portugueuseFolder);
-
-    QDomElement portugueuseKde = doc.createElement(QStringLiteral("outline"));
-    portugueuseKde.setAttribute(QStringLiteral("text"), i18n("Planet KDE Brazilian Portuguese"));
-    portugueuseKde.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("https://planetkde.org/pt-br/rss20.xml"));
-    portugueuseFolder.appendChild(portugueuseKde);
-
     // spanish feed(s)
     QDomElement spanishFolder = doc.createElement(QStringLiteral("outline"));
     spanishFolder.setAttribute(QStringLiteral("text"), i18n("Spanish feeds"));
@@ -210,6 +201,26 @@ static QDomDocument createDefaultFeedList()
     gnuReddit.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("http://www.reddit.com/r/gnu/.rss"));
     fsFolder.appendChild(gnuReddit);
 
+    // kubuntu feed(s)
+    QDomElement kubuntuFolder = doc.createElement(QStringLiteral("outline"));
+    kubuntuFolder.setAttribute(QStringLiteral("text"), QStringLiteral("Kubuntu"));
+    body.appendChild(kubuntuFolder);
+
+    QDomElement planet = doc.createElement(QStringLiteral("outline"));
+    planet.setAttribute(QStringLiteral("text"), i18n("Planet Ubuntu"));
+    planet.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("http://planet.ubuntu.com/rss20.xml"));
+    kubuntuFolder.appendChild(planet);
+
+    QDomElement fridge = doc.createElement(QStringLiteral("outline"));
+    fridge.setAttribute(QStringLiteral("text"), i18n("Ubuntu Fridge"));
+    fridge.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("http://feeds.feedburner.com/ubuntu-fridge"));
+    kubuntuFolder.appendChild(fridge);
+
+    QDomElement ktimes = doc.createElement(QStringLiteral("outline"));
+    ktimes.setAttribute(QStringLiteral("text"), i18n("Kubuntu.org News"));
+    ktimes.setAttribute(QStringLiteral("xmlUrl"), QStringLiteral("http://www.kubuntu.org/news/feed"));
+    kubuntuFolder.appendChild(ktimes);
+
     return doc;
 }
 }
@@ -302,21 +313,16 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     // notify the part that this is our internal widget
     setWidget(mCentralWidget);
 
+    //Initialize instance.
+    (void)UnityServiceManager::instance();
+    if (Settings::showUnreadInTaskbar()) {
+        connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, UnityServiceManager::instance(), &UnityServiceManager::slotSetUnread);
+    }
+
     if (Settings::showTrayIcon() && !TrayIcon::getInstance()) {
-        TrayIcon *trayIcon = new TrayIcon(m_mainWidget->window());
-        TrayIcon::setInstance(trayIcon);
-        m_actionManager->setTrayIcon(trayIcon);
-
-        if (isTrayIconEnabled()) {
-            trayIcon->setStatus(KStatusNotifierItem::Active);
-        }
-
+        initializeTrayIcon();
         QWidget *const notificationParent = isTrayIconEnabled() ? m_mainWidget->window() : nullptr;
         NotificationManager::self()->setWidget(notificationParent, componentData().componentName());
-
-        connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, trayIcon, &TrayIcon::slotSetUnread);
-        connect(m_mainWidget.data(), &MainWidget::signalArticlesSelected,
-                this, &Part::signalArticlesSelected);
     }
 
     connect(qApp, &QCoreApplication::aboutToQuit, this, &Part::slotOnShutdown);
@@ -325,14 +331,6 @@ Part::Part(QWidget *parentWidget, QObject *parent, const QVariantList &)
     connect(m_autosaveTimer, &QTimer::timeout, this, &Part::slotSaveFeedList);
     m_autosaveTimer->start(5 * 60 * 1000); // 5 minutes
 
-    QString useragent = QStringLiteral("Akregator/%1; syndication").arg(QStringLiteral(AKREGATOR_VERSION));
-
-    if (!Settings::customUserAgent().isEmpty()) {
-        useragent = Settings::customUserAgent();
-    }
-
-    Syndication::FileRetriever::setUserAgent(useragent);
-
     loadPlugins(QStringLiteral("extension"));   // FIXME: also unload them!
     if (mCentralWidget->previousSessionCrashed()) {
         mCentralWidget->needToRestoreCrashedSession();
@@ -390,46 +388,60 @@ void Part::slotOnShutdown()
     delete TrayIcon::getInstance();
     TrayIcon::setInstance(nullptr);
     delete m_storage;
-    m_storage = 0;
+    m_storage = nullptr;
     //delete m_actionManager;
 }
 
+void Part::initializeTrayIcon()
+{
+    TrayIcon *trayIcon = new TrayIcon(m_mainWidget->window());
+    TrayIcon::setInstance(trayIcon);
+    m_actionManager->setTrayIcon(trayIcon);
+
+    if (isTrayIconEnabled()) {
+        trayIcon->setStatus(KStatusNotifierItem::Active);
+    }
+
+    connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, trayIcon, &TrayIcon::slotSetUnread);
+    connect(m_mainWidget.data(), &MainWidget::signalArticlesSelected,
+            this, &Part::signalArticlesSelected);
+
+    m_mainWidget->slotSetTotalUnread();
+}
+
 void Part::slotSettingsChanged()
 {
+    if (Settings::showUnreadInTaskbar()) {
+        connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, UnityServiceManager::instance(), &UnityServiceManager::slotSetUnread);
+        m_mainWidget->slotSetTotalUnread();
+    } else {
+        disconnect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, UnityServiceManager::instance(), &UnityServiceManager::slotSetUnread);
+        UnityServiceManager::instance()->slotSetUnread(0);
+    }
+
     NotificationManager::self()->setWidget(isTrayIconEnabled() ? m_mainWidget->window() : nullptr, componentData().componentName());
 
-    if (Settings::showTrayIcon() && !TrayIcon::getInstance()) {
-        TrayIcon *trayIcon = new TrayIcon(m_mainWidget->window());
-        TrayIcon::setInstance(trayIcon);
-        m_actionManager->setTrayIcon(trayIcon);
-
-        if (isTrayIconEnabled()) {
-            trayIcon->setStatus(KStatusNotifierItem::Active);
+    if (Settings::showTrayIcon()) {
+        if (!TrayIcon::getInstance()) {
+            initializeTrayIcon();
+            m_mainWidget->slotSetTotalUnread();
         }
-
-        connect(m_mainWidget.data(), &MainWidget::signalUnreadCountChanged, trayIcon, &TrayIcon::slotSetUnread);
-        connect(m_mainWidget.data(), &MainWidget::signalArticlesSelected,
-                this, &Part::signalArticlesSelected);
-
-        m_mainWidget->slotSetTotalUnread();
-    }
-    if (!Settings::showTrayIcon()) {
+    } else {
         TrayIcon::getInstance()->disconnect();
         delete TrayIcon::getInstance();
         TrayIcon::setInstance(nullptr);
         m_actionManager->setTrayIcon(nullptr);
     }
 
-    Syndication::FileRetriever::setUseCache(Settings::useHTMLCache());
-
-    QStringList fonts;
-    fonts.append(Settings::standardFont());
-    fonts.append(Settings::fixedFont());
-    fonts.append(Settings::sansSerifFont());
-    fonts.append(Settings::serifFont());
-    fonts.append(Settings::standardFont());
-    fonts.append(Settings::standardFont());
-    fonts.append(QStringLiteral("0"));
+    const QStringList fonts {
+        Settings::standardFont(),
+        Settings::fixedFont(),
+        Settings::sansSerifFont(),
+        Settings::serifFont(),
+        Settings::standardFont(),
+        Settings::standardFont(),
+        QStringLiteral("0")
+    };
     Settings::setFonts(fonts);
 
     if (Settings::minimumFontSize() > Settings::mediumFontSize()) {
@@ -437,6 +449,8 @@ void Part::slotSettingsChanged()
     }
     saveSettings();
     Q_EMIT signalSettingsChanged();
+
+    initFonts();
 }
 
 void Part::slotSetStatusText(const QString &statusText)
@@ -559,7 +573,7 @@ void Part::flushAddFeedRequests()
     }
 
     for (const AddFeedRequest &i : qAsConst(m_requests)) {
-        Q_FOREACH (const QString &j, i.urls) {
+        for (const QString &j : qAsConst(i.urls)) {
             m_mainWidget->addFeedToGroup(j, i.group);
         }
         NotificationManager::self()->slotNotifyFeeds(i.urls);
@@ -589,7 +603,7 @@ void Part::slotSaveFeedList()
     if (xml.isEmpty()) {
         return;
     }
-    
+
     m_storage->storeFeedList(xml);
     if (writeToTextFile(xml, localFilePath())) {
         return;
@@ -716,10 +730,10 @@ void Part::showOptions()
 
     if (!m_dialog) {
         m_dialog = new KCMultiDialog(m_mainWidget);
-        connect(m_dialog, QOverload<>::of(&KCMultiDialog::configCommitted),
+        connect(m_dialog, qOverload<>(&KCMultiDialog::configCommitted),
                 this, &Part::slotSettingsChanged);
         if (TrayIcon::getInstance()) {
-            connect(m_dialog, QOverload<>::of(&KCMultiDialog::configCommitted),
+            connect(m_dialog, qOverload<>(&KCMultiDialog::configCommitted),
                     TrayIcon::getInstance(), &TrayIcon::settingsChanged);
         }
 
@@ -806,7 +820,24 @@ bool Part::handleCommandLine(const QStringList &args)
     QStringList feedsToAdd = parser.values(QStringLiteral("addfeed"));
 
     if (feedsToAdd.isEmpty() && !parser.positionalArguments().isEmpty()) {
-        Q_FOREACH (const QString &url, parser.positionalArguments()) {
+        const auto positionalArguments = parser.positionalArguments();
+        for (QString url : positionalArguments) {
+            const QUrl tempUrl = QUrl::fromUserInput(url);
+            if (tempUrl.isLocalFile()) {
+                const QString tempLocalFile = tempUrl.toLocalFile();
+                if (tempLocalFile.startsWith(QDir::tempPath())) {
+                    const QString path = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QStringLiteral("/akregator/data/");
+                    QDir().mkpath(path);
+                    QFile f(tempLocalFile);
+                    const QString newRssFileName = path + QFileInfo(f).fileName();
+                    if (!f.copy(newRssFileName)) {
+                        qCWarning(AKREGATOR_LOG) << "Impossible to copy in local folder" << newRssFileName;
+                    } else {
+                        url = newRssFileName;
+                    }
+                }
+            }
+
             feedsToAdd.append(url);
         }
     }
